@@ -4,22 +4,30 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(Parser)]
-#[grammar = "peg/csharp.pest"]
+#[grammar = "grammar/csharp.pest"]
 struct CSharpParser;
 
 #[allow(dead_code)]
-pub fn format_csharp(text: &str, lint: bool) -> String {
-  let pairs = CSharpParser::parse(Rule::item, text);
-  return code::format_pairs(text, pairs, lint);
+pub fn format_csharp(text: &str) -> code::FormatResult {
+    let pairs = CSharpParser::parse(Rule::item, text);
+    let text = code::FormatResult::new(text);
+    return code::format_pairs(text, pairs);
+}
+
+#[allow(dead_code)]
+pub fn lint_csharp(text: &str) -> code::LintResult {
+    let pairs = CSharpParser::parse(Rule::item, text);
+    let text = code::LintResult::new(text);
+    return code::format_pairs(text, pairs);
 }
 
 #[cfg(test)]
 mod tests {
-  use super::*;
+    use super::*;
 
-  #[test]
-  fn it_format_csharp() {
-    let example = r###"
+    #[test]
+    fn it_format_csharp() {
+        let example = r###"
 /**
  * 第1行注释
  * 第2行注释
@@ -36,7 +44,7 @@ public String helloWorld(stirng name) {
 }
 "###;
 
-    let expect = r###"
+        let expect = r###"
 /**
  * 第 1 行注释
  * 第 2 行注释
@@ -53,6 +61,6 @@ public String helloWorld(stirng name) {
 }
 "###;
 
-    assert_eq!(expect, format_csharp(example, false));
-  }
+        assert_eq!(expect, format_csharp(example).to_string());
+    }
 }
