@@ -4,22 +4,30 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(Parser)]
-#[grammar = "peg/dart.pest"]
+#[grammar = "grammar/dart.pest"]
 struct DartParser;
 
 #[allow(dead_code)]
-pub fn format_dart(text: &str, lint: bool) -> String {
-  let pairs = DartParser::parse(Rule::item, text);
-  return code::format_pairs(text, pairs, lint);
+pub fn format_dart(text: &str) -> code::FormatResult {
+    let pairs = DartParser::parse(Rule::item, text);
+    let out = code::FormatResult::new(text);
+    return code::format_pairs(out, pairs);
+}
+
+#[allow(dead_code)]
+pub fn lint_dart(text: &str) -> code::LintResult {
+    let pairs = DartParser::parse(Rule::item, text);
+    let out = code::LintResult::new(text);
+    return code::format_pairs(out, pairs);
 }
 
 #[cfg(test)]
 mod tests {
-  use super::*;
+    use super::*;
 
-  #[test]
-  fn it_format_dart() {
-    let example = r###"
+    #[test]
+    fn it_format_dart() {
+        let example = r###"
 /** 
  * 第1行注释
  * 第2行注释
@@ -41,7 +49,7 @@ String helloWorld(String name) {
 }
 "###;
 
-    let expect = r###"
+        let expect = r###"
 /** 
  * 第 1 行注释
  * 第 2 行注释
@@ -63,6 +71,6 @@ String helloWorld(String name) {
 }
 "###;
 
-    assert_eq!(expect, format_dart(example, false));
-  }
+        assert_eq!(expect, format_dart(example).to_string());
+    }
 }
