@@ -4,22 +4,30 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(Parser)]
-#[grammar = "peg/go.pest"]
+#[grammar = "grammar/go.pest"]
 struct GoParser;
 
 #[allow(dead_code)]
-pub fn format_go(text: &str, lint: bool) -> String {
-  let pairs = GoParser::parse(Rule::item, text);
-  return code::format_pairs(text, pairs, lint);
+pub fn format_go(text: &str) -> code::FormatResult {
+    let pairs = GoParser::parse(Rule::item, text);
+    let text = code::FormatResult::new(text);
+    return code::format_pairs(text, pairs);
+}
+
+#[allow(dead_code)]
+pub fn lint_go(text: &str) -> code::LintResult {
+    let pairs = GoParser::parse(Rule::item, text);
+    let text = code::LintResult::new(text);
+    return code::format_pairs(text, pairs);
 }
 
 #[cfg(test)]
 mod tests {
-  use super::*;
+    use super::*;
 
-  #[test]
-  fn it_format_go() {
-    let example = r###"
+    #[test]
+    fn it_format_go() {
+        let example = r###"
 // WithContext创建基于ctx的db
 // 第2行注释
 func (d *Dao) WithContext(ctx context.Context) (db *gorm.DB) {
@@ -34,7 +42,7 @@ func (d *Dao) WithContext(ctx context.Context) (db *gorm.DB) {
 }
 "###;
 
-    let expect = r###"
+        let expect = r###"
 // WithContext 创建基于 ctx 的 db
 // 第 2 行注释
 func (d *Dao) WithContext(ctx context.Context) (db *gorm.DB) {
@@ -49,6 +57,6 @@ func (d *Dao) WithContext(ctx context.Context) (db *gorm.DB) {
 }
 "###;
 
-    assert_eq!(expect, format_go(example, false));
-  }
+        assert_eq!(expect, format_go(example).to_string());
+    }
 }
