@@ -4,22 +4,30 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(Parser)]
-#[grammar = "peg/java.pest"]
+#[grammar = "grammar/java.pest"]
 struct JavaParser;
 
 #[allow(dead_code)]
-pub fn format_java(text: &str, lint: bool) -> String {
-  let pairs = JavaParser::parse(Rule::item, text);
-  return code::format_pairs(text, pairs, lint);
+pub fn format_java(text: &str) -> code::FormatResult {
+    let pairs = JavaParser::parse(Rule::item, text);
+    let text = code::FormatResult::new(text);
+    return code::format_pairs(text, pairs);
+}
+
+#[allow(dead_code)]
+pub fn lint_java(text: &str) -> code::LintResult {
+    let pairs = JavaParser::parse(Rule::item, text);
+    let text = code::LintResult::new(text);
+    return code::format_pairs(text, pairs);
 }
 
 #[cfg(test)]
 mod tests {
-  use super::*;
+    use super::*;
 
-  #[test]
-  fn it_format_java() {
-    let example = r###"
+    #[test]
+    fn it_format_java() {
+        let example = r###"
 // 第1行注释
 // 第2行注释
 public String helloWorld() {
@@ -37,7 +45,7 @@ public String helloWorld() {
 }
 "###;
 
-    let expect = r###"
+        let expect = r###"
 // 第 1 行注释
 // 第 2 行注释
 public String helloWorld() {
@@ -55,6 +63,6 @@ public String helloWorld() {
 }
 "###;
 
-    assert_eq!(expect, format_java(example, false));
-  }
+        assert_eq!(expect, format_java(example).to_string());
+    }
 }
