@@ -4,22 +4,30 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(Parser)]
-#[grammar = "peg/kotlin.pest"]
+#[grammar = "grammar/kotlin.pest"]
 struct KotlinParser;
 
 #[allow(dead_code)]
-pub fn format_kotlin(text: &str, lint: bool) -> String {
-  let pairs = KotlinParser::parse(Rule::item, text);
-  return code::format_pairs(text, pairs, lint);
+pub fn format_kotlin(text: &str) -> code::FormatResult {
+    let pairs = KotlinParser::parse(Rule::item, text);
+    let text = code::FormatResult::new(text);
+    return code::format_pairs(text, pairs);
+}
+
+#[allow(dead_code)]
+pub fn lint_kotlin(text: &str) -> code::LintResult {
+    let pairs = KotlinParser::parse(Rule::item, text);
+    let text = code::LintResult::new(text);
+    return code::format_pairs(text, pairs);
 }
 
 #[cfg(test)]
 mod tests {
-  use super::*;
+    use super::*;
 
-  #[test]
-  fn it_format_kotlin() {
-    let example = r###"
+    #[test]
+    fn it_format_kotlin() {
+        let example = r###"
 /** 
  * 第1行注释
  * 第2行注释
@@ -35,7 +43,7 @@ fun helloWorld(name: String) {
 }
 "###;
 
-    let expect = r###"
+        let expect = r###"
 /** 
  * 第 1 行注释
  * 第 2 行注释
@@ -51,6 +59,6 @@ fun helloWorld(name: String) {
 }
 "###;
 
-    assert_eq!(expect, format_kotlin(example, false));
-  }
+        assert_eq!(expect, format_kotlin(example).to_string());
+    }
 }
