@@ -4,22 +4,30 @@ use pest::Parser as P;
 use pest_derive::Parser;
 
 #[derive(Parser)]
-#[grammar = "peg/sql.pest"]
+#[grammar = "grammar/sql.pest"]
 struct SQLParser;
 
 #[allow(dead_code)]
-pub fn format_sql(text: &str, lint: bool) -> String {
-  let pairs = SQLParser::parse(Rule::item, text);
-  return code::format_pairs(text, pairs, lint);
+pub fn format_sql(text: &str) -> code::FormatResult {
+    let pairs = SQLParser::parse(Rule::item, text);
+    let text = code::FormatResult::new(text);
+    return code::format_pairs(text, pairs);
+}
+
+#[allow(dead_code)]
+pub fn lint_sql(text: &str) -> code::LintResult {
+    let pairs = SQLParser::parse(Rule::item, text);
+    let text = code::LintResult::new(text);
+    return code::format_pairs(text, pairs);
 }
 
 #[cfg(test)]
 mod tests {
-  use super::*;
+    use super::*;
 
-  #[test]
-  fn it_format_sql() {
-    let example = r#"
+    #[test]
+    fn it_format_sql() {
+        let example = r#"
 SELECT * FROM "topics" WHERE "id" = ?;
 COMMENT ON COLUMN "topics"."user_id" IS 'topic创建者';
 -- Comment注释信息
@@ -31,7 +39,7 @@ COMMENT ON COLUMN "topics"."status" IS '3屏蔽 1审核中 2已发布';
 COMMENT ON COLUMN "topics"."kind" IS '0普通 1转发';
 "#;
 
-    let expect = r#"
+        let expect = r#"
 SELECT * FROM "topics" WHERE "id" = ?;
 COMMENT ON COLUMN "topics"."user_id" IS 'topic 创建者';
 -- Comment 注释信息
@@ -43,6 +51,6 @@ COMMENT ON COLUMN "topics"."status" IS '3 屏蔽 1 审核中 2 已发布';
 COMMENT ON COLUMN "topics"."kind" IS '0 普通 1 转发';
 "#;
 
-    assert_eq!(expect, format_sql(example, false));
-  }
+        assert_eq!(expect, format_sql(example).to_string());
+    }
 }
